#pragma rtGlobals=3		// Use modern global access method and strict wave access.

//	Use this macro to calibrate an image or map (with decimal degrees) that is loaded 
//	into an IGOR experiment as an image.

//	Before running the macro, locate 3 points on the graph with known values. Usually
//	this is most easily done on the axes. 

	
	Function Calibrate_Image()
		SetDataFolder root:
			String/G G_Image
			String Image
			Make/O/N = 3 X_Val, Y_Val, X_Pixel, Y_Pixel
			Prompt Image, "Image:",popup, wavelist("*",";","DIMS:3") 		// Choose the image to be calibrated
			DoPrompt "Calibrate_Image", Image; AbortOnValue V_Flag, 0
			Variable i, XValue, YValue
			For( i = 0; i < 3; ++ i )
				PauseForCursor()
				Prompt XValue, "X Value of Cursor A"
				Prompt YValue, "Y Value of Cursor A"
				DoPrompt "Calibrate_Image", XValue, YValue
				X_Val[ i ] = XValue; X_Pixel[ i ] = PCsr( A )
				Y_Val[ i ] = YValue; Y_Pixel[ i ] = QCsr( A )
			EndFor
			PauseUpdate;

			CurveFit/Q line  X_Val /X = X_Pixel /D 		// A linear fit is done between the X data values and pixel values
			WAVE W_Coef
			SetScale/P x W_Coef[0], W_Coef[1],"", $Image;DelayUpdate	// The X scaling of the image is rescaled using the
																									// slope-intercept form using the coefficients of the 																// lines fit
			CurveFit/Q line  Y_Val /X = Y_Pixel /D 						// The same is done for the Y axis of the image
			SetScale/P y W_Coef[0], W_Coef[1],"", $Image;DelayUpdate
			KillWaves/Z fit_X_Val, fit_y_Val, W_coef, W_Sigma, X_Pixel, X_Val, Y_Pixel, Y_Val
	End

#Include "PauseForCursor"	

	
	
	Menu "Macros"
		"Calibrate_Image"
	end
