#pragma rtGlobals=1		// Use modern global access method.

// This macro sets up the graph for core stretching. Single cores are displayed next to a spliced image so that tie points can be chosen.

	Function Core_Stretch_Image_SetUp( )
		SetDataFolder root:
			String/G G_Hole, G_Core_Image
			Variable i = 0;
			String Hole = G_Hole, Spliced_Image, Core_Image = G_Core_Image
			Prompt Hole, "Hole:"
			DoPrompt "Core_Stretch_Image_SetUp", Hole; AbortOnValue V_Flag, 0
			G_Hole = Hole
			String Site = RemoveEnding( Hole )
			String HoleLetter = Hole[ StrLen( Hole ) - 1 ]
			WAVE SplicedImg = $Site + "_Splice"
			Make/O/N = 0 Core_Ties, Splice_Ties
			If( !DataFolderExists( Site + "_Splice_Intervals" ) )
				Abort "This function needs the folder " + Site + "_Splice_Intervals to identify spliced intervals on the cores."
			EndIf
		SetDataFolder $Site + "_Splice_Intervals"
			WAVE CCSF_Top, CCSF_Bottom
			WAVE/T  Hole_Top
		NewDataFolder/O/S root:Xtras
			Make/O/N = 0 Numbers, Ones; 
			Duplicate/O CCSF_Top HoleSplTop, HoleSplBottom, HoleFilter
			HoleFilter = StringMatch( HoleLetter, Hole_Top )
			HoleFilter = HoleFilter == 0 ? NaN : HoleFilter
			HoleSplTop = HoleFilter * CCSF_Top
			HoleSplBottom = HoleFilter * CCSF_Bottom
		SetDataFolder $"root:" + Hole + "_S2"
			Prompt Core_Image, "Core Image:", popup, WaveList( "S2*", ";", "DIMS:3" );
			DoPrompt "Core_Stretch_Image_SetUp", Core_Image; AbortOnValue V_Flag, 0
			WAVE CoreImg = $Core_Image	
			String Core = Core_Image[ 3, inf]
		NewDataFolder/O/S $"root:" + Hole + "_Tie_Points" 
			If( Exists( Core + "_Core_Ties" ) )
				Duplicate/O $Core + "_Core_Ties" Core_Ties
				Duplicate/O $Core + "_Splice_Ties" Splice_Ties
			Else
				Make/O/N = 0 $Core + "_Core_Ties", $Core + "_Splice_Ties"
				WAVE CTies = $Core + "_Core_Ties", STies = $Core + "_Splice_Ties"
				For( i = 0; i < NumPnts( HoleFilter ); i += 1 )
					If( HoleSplTop[ i ] >= LeftX( CoreImg )  && HoleSplBottom[ i ] < RightX( CoreImg ) )
						InsertPoints 0, 2, CTies, STies
						CTies[ 0 ] = HoleSplTop[ i ]
						CTies[ 1 ] = HoleSplBottom[ i ]
						Duplicate/O CTies STies, Core_Ties, Splice_Ties
					EndIf
				EndFor
			EndIf
			If( StrSearch( WinList( "*", ";", "WIN:2" ),"Core_Tie_Table", 0 ) == -1 )
				EXECUTE "Core_Tie_Table()"
			EndIf
		SetDataFolder root:Xtras
			Duplicate/O Core_Ties Numbers, Ones
			Numbers = x; Ones = .5
		SetDataFolder root:
			PauseUpdate;
			Duplicate/O SplicedImg Interp_Image;
			Interp_Image = nan;
			Display;AppendImage/L=Spliced_Image_Axis SplicedImg;
			SetAxis Bottom LeftX( CoreImg ) - 1, RightX( CoreImg ) + 1
			AppendImage/R=Stretched_Axis Interp_Image;
			AppendImage/R=Core_Image_Axis CoreImg
			ModifyGraph axisEnab(Stretched_Axis)={0.67,1.0}
			ModifyGraph axisEnab(Spliced_Image_Axis)={0.34,0.65}
			ModifyGraph axisEnab(Core_Image_Axis)={0.0,0.32}
			ModifyGraph minor(bottom)=1
			ModifyGraph noLabel(Spliced_Image_Axis)=2,noLabel(Stretched_Axis)=2,noLabel(Core_Image_Axis)=2;DelayUpdate
			ModifyGraph freePos(Core_Image_Axis)=0, freePos(Stretched_Axis)=0, freePos(Spliced_Image_Axis)=0
			ModifyGraph nticks(bottom)=10
			ModifyGraph tick(Spliced_Image_Axis)=3,tick(Stretched_Axis)=3,tick(Core_Image_Axis)=3
			ShowInfo;
			AppendToGraph/L = Ones Ones vs Splice_Ties
			SetAxis Ones 0,1 
			ModifyGraph axisEnab(Ones)={0.33,0.66}
			ModifyGraph mode=3, rgb=(65535,0,0)
			ModifyGraph textMarker(Ones)={Numbers,"default",1,0,5,0.00,0.00}
			ModifyGraph tick(Ones)=3,noLabel(Ones)=2,freePos(Ones)=0
			AppendToGraph/L=Ones_2 Ones vs Core_Ties
			SetAxis Ones_2 0,1 
			ModifyGraph axisEnab(Ones_2)={0,0.33}
			ModifyGraph mode=3, rgb=(65535,0,0)
			ModifyGraph textMarker(Ones#1)={Numbers,"default",1,0,5,0.00,0.00}
			ModifyGraph tick(Ones_2)=3,noLabel(Ones_2)=2,freePos(Ones_2)=0
			ModifyGraph msize=5
			Cursor/I A, $Site + "_Splice", LeftX( SplicedImg ), .5
			Cursor/I B, $Core_Image, LeftX( CoreImg ), .5
			Set_Cursors_Red()
		SetDataFolder root:
	End
		
	Window Core_Tie_Table() : Table
		PauseUpdate; Silent 1		// building window...
		Edit/W=(107,645,363,845) Core_Ties,Splice_Ties as "Core_Tie_Table"
		ModifyTable format(Point)=1,alignment(Core_Ties)=1,format(Core_Ties)=3,digits(Core_Ties)=2
		ModifyTable alignment(Splice_Ties)=1,format(Splice_Ties)=3,digits(Splice_Ties)=2
	EndMacro
