#pragma rtGlobals=1		// Use modern global access method.

	Menu "Macros"
		"Create_Long_Coring_Matrix"
	End

-----------------------------------------------------------------------
//
// Create_Coring_Matrix( ) is used to initialize a 100 X 10 X 3 wave that has Rows (100 ) = Cores and 
//		Columns (10 ) = Sections. The top layer holds the csf depth to the top of a section. The second
//		layer holds the section length, and the third layer holds the ccsf-a depth to the top of a section.
//
//		The Coring Matrix is necessary to assign depths to core images as they are loaded and combined
//		into complete core images.
//
//		The data necessary can be downloaded from Web Tabular under Summaries/Section Summaries.
//		Cut & Paste columns and use the pulldown menus to identify Core, Section, Length, and CSF/mbsf
// 
//		Once the matrix is formed use Add_Offsets( ) to fill in the CCSF depth values once the offset tables are 
//		added.

	Function Create_Long_Coring_Matrix( )
		SetDataFolder root:
			Variable i = 0, Core, Section, CoreMax, SectionMax
			String/G G_Hole, G_S1, G_S2, G_S3, G_S4, G_YesNo
			String  WList = WaveList( "*", ";", "" ), S_Hole = G_Hole, CSFWave = G_S1, CoreWave = G_S2, SectionWave = G_S3, LengthWave = G_S4, YN = G_YesNo
			Prompt S_Hole "Hole:"
			Prompt CSFWave "CSF or mbsf Wave:", popup, WList
			Prompt CoreWave "Core Number Wave", popup, WList
			Prompt  SectionWave "Section Number Wave:",popup, WList
			Prompt LengthWave "Section Length Wave:", popup, WList
			Prompt YN "Replace CC as Section 19?", popup, "Y;N"
//			Prompt YN "Replace CC as Section 9?", popup, "Y;N"
			DoPrompt "Create_Coring_Matrix", S_Hole, CSFWave, CoreWave, SectionWave, LengthWave, YN; AbortOnValue( V_Flag ), 1
			G_Hole = S_Hole; G_S1 = CSFWave; G_S2 = CoreWave; G_S3 = SectionWave; G_S4 = LengthWave; G_YesNo = YN
			PauseUpdate
	
			WAVE CSFW = $CSFWave, CoreW = $CoreWave, SectionW = $SectionWave, LengthW = $LengthWave	
			WaveStats/Q SectionW
			SectionMax = V_Max
			WaveStats/Q CoreW
			CoreMax = V_Max
	
			If( Exists( S_Hole + "_Coring_Matrix" ) == 1 )
				DoAlert 1, S_Hole + "_Coring_Matrix already exists.\r\rDo you want to overwrite it?"
				AbortOnValue ( V_Flag == 2 ), 0				
			EndIf		
			
//			If( SectionMax > 8 )
//				DoAlert 1, "At least 1 core has more than 8 sections. This will cause \rproblems if CC's are designated as Section 9.\r\rIgnore if this is an overwrite of an existing matrix.\r\rDo you want to proceed?"
//				AbortOnValue ( V_Flag == 2 ), 0
//			EndIf

			If( StringMatch( YN, "Y" ) )
				SectionW = SectionW > 0 ? SectionW : 19
//				SectionW = SectionW > 0 ? SectionW : 9
			EndIf

//			Make/O/N = ( ( CoreMax + 1 ), ( 15 ), 3 ) $( S_Hole + "_Coring_Matrix" )
			Make/O/N = ( ( CoreMax + 1 ), ( 20 ), 3 ) $( S_Hole + "_Coring_Matrix" )
			WAVE Matrix = $( S_Hole + "_Coring_Matrix" )
			Matrix = NaN
			If( WaveType( SectionW, 1 ) == 2 )
				Abort "PROBLEM - The Section wave was loaded as a TEXT wave.\r  This usually occurs when the Section in the first line of the\r  external data file is a \"CC\".\r  You will need to substitute \"9\" for CC in the first line of the external file and load again."
			EndIf
				
			Do
				Core = CoreW[ i ]
				Section = SectionW[ i ]
				If( NumType( Section ) != 2 )
					Matrix[ Core ][ Section ][ 0 ] = CSFW[ i ]
					Matrix[ Core ][ Section ][ 1 ] = LengthW[ i ]
				EndIf
				i += 1
			While( i <= V_Npnts )
			Matrix[ 0 ][ 0 ][ 0 ] = NaN
	EndMacro




