﻿#pragma TextEncoding = "UTF-8"
#pragma rtGlobals=3		// Use modern global access method and strict wave access.

// This Function can combine benthic isotope data from different species in one table per Hole; The data table needs to
// have UXXX_ISOBEN_Site, _Hole, _Core, _Type, _Section, _Interval, _CSF, _CCSF, _Source, _Note in it. The Datawave 
// with the isotope data from each sepcies need to be UXXX_ISOBEN_CWUEd13C and UXXX_ISOBEN_CWUEd18O (CWUE as example for
// C. wuellerstorfi). If the data also have been squeezed and stretched to the composite depth please add 
// UXXX_ISOBEN_CCSFOffspl and modify the Function below to include this.

Menu "Macros"
"ISOBEN_COMBINE"
End

#Include "folderlist"		// loads funtion folderlist

Function ISOBEN_COMBINE()
	SetDataFolder root:
		String/G G_Hole, G_Folder
		String Hole = G_Hole, Folder = G_Folder
		Prompt Folder,"Folder", popup, folderlist("*")
		Prompt Hole,"Hole"
		DoPrompt "ISOBEN_COMBINE", Folder, Hole; AbortonValue V_Flag,0
		G_Hole = Hole; G_Folder = Folder
		String Site = Removeending(Hole)
	SetDataFolder $Folder
		Wave Core = $Hole + "_ISOBEN_Core", Section = $Hole + "_ISOBEN_Section", Interval = $Hole + "_ISOBEN_Interval"
		Wave CSF = $Hole + "_ISOBEN_CSF", CCSF = $Hole + "_ISOBEN_CCSF", CCSFadj = $Hole + "_ISOBEN_CCSFOffspl"
		Wave /T DrillSite = $Hole + "_ISOBEN_Site", DrillHole = $Hole + "_ISOBEN_Hole", Type = $Hole + "_ISOBEN_Type"
		Wave /T Spcs = $Hole + "_ISOBEN_Species"
		Wave /T Sour =$Hole + "_ISOBEN_Source", Not = $Hole + "_ISOBEN_Note"
	SetDataFolder root:
	NewDataFolder/O/S $Site + "_ISOBENall"			// form data folder
		Make /O/T/N=0 $Hole+"_ISOBENall_Site", $Hole+"_ISOBENall_Hole"
		Make	/O/N=0 $Hole+"_ISOBENall_Core"
		Make	/O/T/N=0, $Hole+"_ISOBENall_Type"
		Make /O/N=0 $Hole+"_ISOBENall_Section", $Hole+"_ISOBENall_Interval", $Hole+"_ISOBENall_CSF"
		Make /O/N=0 $Hole+"_ISOBENall_CCSF", $Hole+"_ISOBENall_CCSFOffspl"
		Make	/O/N=0 $Hole+"_ISOBENall_d13C", $Hole+"_ISOBENall_d18O"
		Make /O/T/N=0 $Hole+"_ISOBENall_Species", $Hole+"_ISOBENall_Source", $Hole+"_ISOBENall_Note"
		Wave IsoCore = $Hole+"_ISOBENall_Core", IsoSection = $Hole+"_ISOBENall_Section"
		Wave IsoInterval = $Hole+"_ISOBENall_Interval", IsoCSF = $Hole+"_ISOBENall_CSF"
		Wave d13C = $Hole+"_ISOBENall_d13C",d18O = $Hole+"_ISOBENall_d18O", IsoCCSF = $Hole+"_ISOBENall_CCSF"
		Wave dpthadj = $Hole+"_ISOBENall_CCSFOffspl"
		Wave /T IsoSite = $Hole+"_ISOBENall_Site", IsoHole = $Hole+"_ISOBENall_Hole", IsoType = $Hole+"_ISOBENall_Type"
		Wave /T Speciestype = $Hole+"_ISOBENall_Species", Source = $Hole+"_ISOBENall_Source", IsoNote = $Hole+"_ISOBENall_Note"
	SetDataFolder root:

	SetDataFolder root:$Site + "_ISOBEN"
		String d13Clist = SortList( Wavelist(Hole+"*d13C",";","")	 )
		String d18Olist = SortList( Wavelist(Hole+"*d18O",";","")	 )
		Variable i=0
		For(i=0 ; i<itemsinlist(d13Clist) ; i+=1) 				// loop1 for each species
			wave Datawaved13c = $stringfromlist (i, d13Clist)
			wave Datawaved18o = $stringfromlist (i, d18Olist)
			String Name = ThirdPart(Stringfromlist(i, d13Clist))
			String TEMPSpecies = Name [0,(strlen(Name)-5)]
			Variable j=0
			For (j=0 ; j<numpnts(Datawaved13c)	; j+=1)								//loop2 to extract data
				If ( (numtype(Datawaved13c [j]) == 0) || (numtype(Datawaved18o [j] ) == 0) )
				InsertPoints 0,1, d13C, d18O, IsoSite, IsoHole, IsoCore, IsoType, IsoSection, IsoInterval, IsoCSF, IsoCCSF, Speciestype, Source, IsoNote, dpthadj
				d13C[0] = Datawaved13c [j]
				d18O[0] = Datawaved18o [j]
				IsoSite[0] = DrillSite [j]
				IsoHole[0] = DrillHole [j]
				IsoCore[0] = Core [j]											
				IsoType[0] = Type [j]
				IsoSection[0] = Section [j]
				IsoInterval[0] = Interval [j]
				IsoCSF[0] = CSF [j]
				IsoCCSF[0] = CCSF [j]
				Speciestype[0] = TEMPSpecies					
				Source[0] = Sour [j]					
				IsoNote[0] = Not [j]																																				
				dpthadj[0] = CCSFadj [j]
				EndIf			
			Endfor
			
// sort by depth

		Endfor
	SetDataFolder root:
End	