#pragma rtGlobals=1		// Use modern global access method.

**********************************************************************

// Applies lighting correction curves to the R,G, and B layers of the original image. The
//  reultant image waves begin with C_.  The R_fit and other fits come from other functions run earlier.

	
	Function RGB_Lighting_Correction_DF()
		String Section_LIst, Section, Corr_Section
		Variable i = 0, Z, Brightness_Increase = 0
		Silent 1;
		PauseUpdate;
		Duplicate/O R_fit Fit_x // Set up a wave to hold X values of the curve fit for later interpolation
		Fit_X = x	// Assign the X values
		Section_List = WaveList( "K_*", ";", "" )  // Create a list of the section names
		Do  // This loop corrects each section in turn by the fit curves formed by earlier functions
			Section = StringFromList( i, Section_List )  // Choose a section name from the list of sections
			WAVE Sect = $Section  // WAVE assignment
			If( StrLen( Section ) < 2 )  // Check for end of list
				Break
			EndIf
			Corr_Section = "C" + Section[ 1, strlen( Section ) ] // New section name with "C" replacing "K"
			Duplicate/O Sect  M0, $Corr_Section  //Create "C" section and a mask (M0) the same size as the section
			WAVE CorrSect = $Corr_Section  // Wave assignment for lighting corrected section
			Z = DimOffset( Sect, 0 )  // Z is the top depth of the section
		
			Make/O/N = ( DimSize( Sect, 0 ) )  M0_x // M0_x is a wave of the X (depth) values for the section
			CopyScales/P M0, M0_x  // scales M0_x the same as the image
			M0_x = x  // Sets the values of M0_x to the x scaling
			Duplicate/O M0_x  M0_Lightness  //  Creates a lightness curve the same length as the x scaled wave
			
			M0_Lightness = interp( ( M0_x - M0_x[ 0 ] ), Fit_x, R_Fit ) // M0_Lightness is now filled with interpolated values from the 
			Wavestats/Q M0_Lightness											  //   fit to the R data
			M0_Lightness += ABS( V_Min )				// Subtracts the minimum value of the lightness (or fit) curve. V_Min is usually negative, so it is in fact an addition.
//			M0_Lightness -= V_Min				// Subtracts the minimum value of the lightness (or fit) curve. V_Min is usually negative, so it is in fact an addition.
			M0[ ][ ][ 0 ] = M0_Lightness[p]		// Sets the R ( 0 ) layer of M0 to the correction values from the fit.
																//  The R layer of M0 is now a 2D representation of the correction fit curve.
	
			M0_Lightness = interp( ( M0_x - M0_x[ 0 ] ), Fit_x, G_Fit ) // Process is repeated for G & B layers ( 1 & 2 )
			Wavestats/Q M0_Lightness
//			M0_Lightness -= V_Min
			M0_Lightness += ABS( V_Min )				// Subtracts the minimum value of the lightness (or fit) curve. V_Min is usually negative, so it is in fact an addition.
			M0[ ][ ][ 1 ] = M0_Lightness[ p ]
	
			M0_Lightness = interp( ( M0_x - M0_x[ 0 ] ), Fit_x, B_Fit )
			Wavestats/Q M0_Lightness
			M0_Lightness += ABS( V_Min )				// Subtracts the minimum value of the lightness (or fit) curve. V_Min is usually negative, so it is in fact an addition.
//			M0_Lightness -= V_Min
			M0[ ][ ][ 2 ] = M0_Lightness[ p ]
	
			ReDimension/S CorrSect  // Change the corrected section to single precision float wave
			CorrSect -= M0 // Apply the correction values
			CorrSect = Limit( CorrSect, 0, 255 )  // Set values < 0 to 0 and values > 255 to 255
			ReDimension/B/U CorrSect // revert corrected section back to unsigned integer for RGB image

			i += 1;
		While( 1 )
		KillWaves/Z M0, Mask1, Mask2, Mask3, M0_Lightness, M0_x
		KillWaves/Z R_fit, G_Fit, B_fit, fit_Lightness, Fit_x

	End
	
	****************************************************************
	
// Applies the lighting correction curve to the R,G, and B layers of the original image.
	
	
//	Macro RGB_Lighting_Correction()
		String Section_LIst,Section,Corr_Section
		Variable i=0, Z, Brightness_Increase=0
		Silent 1;
		PauseUpdate;
		SetDataFolder root:
		Duplicate/O R_fit Fit_x
		Fit_X=x	
		Section_List = WaveList("K_*",";","")
		Do
			Section=StringFromList(i,Section_List)
			If(StrLen(Section)<2)
				Break
			EndIf
			Corr_Section="C"+Section[1,strlen(Section)]
			Duplicate/O $Section  M0,$Corr_Section,Mask1,Mask2,Mask3
		
			Z=DimOffset($Section,0)
		
			Make/O/N=(DimSize($Section,0)) M0_x
			CopyScales/P M0, M0_x
			M0_x=x
			Duplicate/O M0_x  M0_Lightness
			
			M0_Lightness=interp((M0_x-M0_x[0]),Fit_x,R_Fit)
			Wavestats/Q M0_Lightness
			If( (V_Max-V_Min) > Brightness_Increase )
				Brightness_Increase=(V_Max-V_Min)
			EndIf	
			M0_Lightness-=V_Min
			M0[][][0]=M0_Lightness[p]
			
			M0_Lightness=interp((M0_x-M0_x[0]),Fit_x,G_Fit)
			Wavestats/Q M0_Lightness
			If( (V_Max-V_Min) > Brightness_Increase )
				Brightness_Increase=(V_Max-V_Min)
			EndIf	
			M0_Lightness-=V_Min
			M0[][][1]=M0_Lightness[p]
	
			M0_Lightness=interp((M0_x-M0_x[0]),Fit_x,B_Fit)
			Wavestats/Q M0_Lightness
			If( (V_Max-V_Min) > Brightness_Increase )
				Brightness_Increase=(V_Max-V_Min)
			EndIf	
			M0_Lightness-=V_Min
			M0[][][2]=M0_Lightness[p]
	
			Mask1=(($Section)-M0<=255)&&(($Section)-M0>=1)
			Mask2=(($Section)-M0<1)*1
			Mask3=(($Section)-M0>255)*255
			$Corr_Section=(Mask1*(($Section)-M0))+(Mask2)+(Mask3)
			Adjust_Brightness(Corr_Section,(Brightness_Increase*1.25))
	//		Adjust_Brightness(Corr_Section,((V_Max-V_Min)*1.25))
			i+=1;
		While(1)
		KillWaves/Z M0,Mask1,Mask2,Mask3,M0_Lightness,M0_x
	EndMacro
	
	****************************************************************
