#pragma rtGlobals=1		// Use modern global access method.

Macro First_XRF_Load()
	String S1,S2,S3
	Variable V1, V2, Counter
	Silent 1
	XLLoadWave/O/S="Sheet1"/C=2/W=1/Q  	// Loads data from Excel file
	X_SampleID_/=10											// Changes interval from mm to cm
	S3="U"+(S_FileName[14,18])+"_XRF_"						// Sets Hole and Technique naming string (e.g. U1146A_XRF_). Hole is taken from name of Excel file
	Rename X_SampleID_  $S3+"Interval"						// Renames X_SampleID_ wave to Hole_Technique_Interval (e.g.  U1146A_XRF_Interval)
	Make/O/n=(NumPnts($S3+"Interval")) $S3+"Core", $S3+"Section" // Creates numeric waves for Core and Section using Interval wave to set number of points
	Make/T/O/n=(NumPnts($S3+"Interval")) $S3+"Site", $S3+"Hole", $S3+"Type" // Creates text waves for Site, Hole, and Type
	$S3+"Site"="U"+S_FileName[14,17]							// Next 5 lines fill waves with values from Excel file name.
	$S3+"Hole"=S_FileName[18]
	$S3+"Type"=S_FileName[22]
	$S3+"Core"=Str2Num(S_FileName[20,21])					// Core and section numbers are converted form strings to numbers
	$S3+"Section"=Str2Num(S_FileName[24])

	S1=WaveList("*Area*",";","")									// Creates list of data (all waves with "Area" in name)
	Do															// This loop renames input waves to include Hole_Technique
		S2=StringFromList(Counter,S1)							//		and truncates name to only the element
		If(StrLen(S2)<1)		// Check for end of list of data waves
			Break;
		EndIf
		V1=StrSearch(S2,"_",0)					// Finds the position of the first underscore ("_") in the wave name
		S3="U"+S_FileName[14,18]+"_XRF_"+S2[0,V1-1] // Creates a string that is Hole_Technique_Element
		print s3
		Rename $S2 $S3						// Renames the data wave to the Hole_Technique_Element string
		Counter+=1
	While(1)
	SaveExperiment								// Automatically saves the  experiment
Endmacro

*****************************************************************************

Macro Add_XRF_Data()
	String S1,S2,S3
	Variable V1, V2,Counter
	Silent 1
	XLLoadWave/O/S="Sheet1"/C=2/W=1/Q
	X_SampleID_/=10
	S3="U"+(S_FileName[14,18])+"_XRF_"
	Rename X_SampleID_  $"Interval"
	Make/O/n=(NumPnts($"Interval")) $"Core", $"Section"
	Make/T/O/n=(NumPnts($"Interval")) $"Site", $"Hole", $"Type"
	$"Site"="U"+S_FileName[14,17]
	$"Hole"=S_FileName[18];
	$"Type"=S_FileName[22];
	$"Core"=Str2Num(S_FileName[20,21]);
	$"Section"=Str2Num(S_FileName[24]);		// This macro to here is much the same as First_XRF_Load() except that the waves
												// formed do not have Hole_Technique in their names. Instead the names are generic.

	Concatenate/NP/KILL {Interval}, $S3+"Interval"		// These 6 lines append (concatenate) the newly loaded data onto the end of the existing
	Concatenate/NP/KILL {Site}, $S3+"Site"				//		 data waves that have Hole_Technique in their names.
	Concatenate/NP/KILL {Hole}, $S3+"Hole"
	Concatenate/NP/KILL {Type}, $S3+"Type"
	Concatenate/NP/KILL {Core}, $S3+"Core"
	Concatenate/NP/KILL {Section}, $S3+"Section"
	
	S1=WaveList("*Area*",";","")			// Creates a list of the elemental data waves	
	Do									// This loop appends (concatenates) the elemental data waves to the existing elemental data waves
		S2=StringFromList(Counter,S1)
		If(StrLen(S2)<1)
			Break;
		EndIf
		V1=StrSearch(S2,"_",0)
		S3="U"+S_FileName[14,18]+"_XRF_"+S2[0,V1-1]
		EXECUTE "Concatenate/NP/KILL {"+S2+"}, "+S3
		Counter+=1
	While(1)
	SaveExperiment
	Print S_FileName; 
	DoUpdate;
	Add_XRF_Data()		// This is an example of Recursion. The macro calls itself and restarts - an infinite loop until canceled by user in the opening Dialog.
Endmacro


//  To make a CSF wave all you need to do is
//		(1) duplicate the Interval wave and call it Hole_Technique_CSF (e.g. U1143A_XRF_CSF)
//  		(2) load the appropriate Coring Matrix (e.g. U1143A_Coring_Matrix)
//		(3) on the command line enter: Hole_Technique_CSF=Coring_Matrix[Hole_Technique_Core][Hole_Technique_Section][0]+Hole_Technique_Interval/100
 //				(e.g. U1143A_XRF_CSF=U1143A_Coring_Matrix[U1143A_XRF_Core][U1143A_XRF_Section][0]+U1143A_XRF_Interval/100) 
  

  Window U1143A_XRF_Data() : Table
	PauseUpdate; Silent 1		// building window...
	Edit/W=(87,44,2004,290) U1143A_XRF_Site,U1143A_XRF_Hole,U1143A_XRF_Core,U1143A_XRF_Type as "Sheet1"
	AppendToTable U1143A_XRF_Section,U1143A_XRF_Interval,U1143A_XRF_Al,U1143A_XRF_Si
	AppendToTable U1143A_XRF_P,U1143A_XRF_S,U1143A_XRF_Cl,U1143A_XRF_K,U1143A_XRF_Ca
	AppendToTable U1143A_XRF_Ti,U1143A_XRF_Cr,U1143A_XRF_Mn,U1143A_XRF_Fe,U1143A_XRF_Rh
	AppendToTable U1143A_XRF_Cu,U1143A_XRF_Zn,U1143A_XRF_Ga,U1143A_XRF_Br,U1143A_XRF_Rb
	AppendToTable U1143A_XRF_Sr,U1143A_XRF_Y,U1143A_XRF_Zr,U1143A_XRF_Nb,U1143A_XRF_Mo
	AppendToTable U1143A_XRF_Pb,U1143A_XRF_Bi,U1143A_XRF_Ag,U1143A_XRF_Cd,U1143A_XRF_Sn
	AppendToTable U1143A_XRF_Te,U1143A_XRF_Ba
	ModifyTable format(Point)=1,alignment(U1143A_XRF_Site)=1,alignment(U1143A_XRF_Hole)=1
	ModifyTable alignment(U1143A_XRF_Core)=1,alignment(U1143A_XRF_Type)=1,alignment(U1143A_XRF_Section)=1
	ModifyTable alignment(U1143A_XRF_Interval)=1,width(U1143A_XRF_Interval)=130,alignment(U1143A_XRF_Al)=1
	ModifyTable width(U1143A_XRF_Al)=100,alignment(U1143A_XRF_Si)=1,width(U1143A_XRF_Si)=100
	ModifyTable alignment(U1143A_XRF_P)=1,width(U1143A_XRF_P)=97,alignment(U1143A_XRF_S)=1
	ModifyTable width(U1143A_XRF_S)=96,alignment(U1143A_XRF_Cl)=1,width(U1143A_XRF_Cl)=100
	ModifyTable alignment(U1143A_XRF_K)=1,width(U1143A_XRF_K)=97,alignment(U1143A_XRF_Ca)=1
	ModifyTable width(U1143A_XRF_Ca)=101,alignment(U1143A_XRF_Ti)=1,width(U1143A_XRF_Ti)=62
	ModifyTable alignment(U1143A_XRF_Cr)=1,width(U1143A_XRF_Cr)=64,alignment(U1143A_XRF_Mn)=1
	ModifyTable width(U1143A_XRF_Mn)=67,alignment(U1143A_XRF_Fe)=1,width(U1143A_XRF_Fe)=63
	ModifyTable alignment(U1143A_XRF_Rh)=1,width(U1143A_XRF_Rh)=65,alignment(U1143A_XRF_Cu)=1
	ModifyTable width(U1143A_XRF_Cu)=64,alignment(U1143A_XRF_Zn)=1,width(U1143A_XRF_Zn)=64
	ModifyTable alignment(U1143A_XRF_Ga)=1,width(U1143A_XRF_Ga)=63,alignment(U1143A_XRF_Br)=1
	ModifyTable width(U1143A_XRF_Br)=65,alignment(U1143A_XRF_Rb)=1,width(U1143A_XRF_Rb)=65
	ModifyTable alignment(U1143A_XRF_Sr)=1,width(U1143A_XRF_Sr)=64,alignment(U1143A_XRF_Y)=1
	ModifyTable width(U1143A_XRF_Y)=58,alignment(U1143A_XRF_Zr)=1,width(U1143A_XRF_Zr)=64
	ModifyTable alignment(U1143A_XRF_Nb)=1,width(U1143A_XRF_Nb)=65,alignment(U1143A_XRF_Mo)=1
	ModifyTable width(U1143A_XRF_Mo)=66,alignment(U1143A_XRF_Pb)=1,width(U1143A_XRF_Pb)=65
	ModifyTable alignment(U1143A_XRF_Bi)=1,width(U1143A_XRF_Bi)=63,alignment(U1143A_XRF_Ag)=1
	ModifyTable width(U1143A_XRF_Ag)=63,alignment(U1143A_XRF_Cd)=1,width(U1143A_XRF_Cd)=63
	ModifyTable alignment(U1143A_XRF_Sn)=1,width(U1143A_XRF_Sn)=64,alignment(U1143A_XRF_Te)=1
	ModifyTable width(U1143A_XRF_Te)=63,alignment(U1143A_XRF_Ba)=1,width(U1143A_XRF_Ba)=64
EndMacro